#[repr(C)]pub struct QmiClientAtr {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientAtr structure contains private data and should only be accessed
using the provided API.
Since: 1.34
The QmiClientAtr structure contains private data and should only be accessed
using the provided API.
Since: 1.34
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientAtr
impl !Sync for QmiClientAtr
impl Freeze for QmiClientAtr
impl RefUnwindSafe for QmiClientAtr
impl Unpin for QmiClientAtr
impl UnsafeUnpin for QmiClientAtr
impl UnwindSafe for QmiClientAtr