#[repr(C)]pub struct QmiClientDms {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientDms structure contains private data and should only be accessed
using the provided API.
Since: 1.0
The QmiClientDms structure contains private data and should only be accessed
using the provided API.
Since: 1.0
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientDms
impl !Sync for QmiClientDms
impl Freeze for QmiClientDms
impl RefUnwindSafe for QmiClientDms
impl Unpin for QmiClientDms
impl UnsafeUnpin for QmiClientDms
impl UnwindSafe for QmiClientDms