#[repr(C)]pub struct QmiClientDpm {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientDpm structure contains private data and should only be accessed
using the provided API.
Since: 1.30
The QmiClientDpm structure contains private data and should only be accessed
using the provided API.
Since: 1.30
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientDpm
impl !Sync for QmiClientDpm
impl Freeze for QmiClientDpm
impl RefUnwindSafe for QmiClientDpm
impl Unpin for QmiClientDpm
impl UnsafeUnpin for QmiClientDpm
impl UnwindSafe for QmiClientDpm