#[repr(C)]pub struct QmiClientDsd {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientDsd structure contains private data and should only be accessed
using the provided API.
Since: 1.26
The QmiClientDsd structure contains private data and should only be accessed
using the provided API.
Since: 1.26
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientDsd
impl !Sync for QmiClientDsd
impl Freeze for QmiClientDsd
impl RefUnwindSafe for QmiClientDsd
impl Unpin for QmiClientDsd
impl UnsafeUnpin for QmiClientDsd
impl UnwindSafe for QmiClientDsd