#[repr(C)]pub struct QmiClientFox {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientFox structure contains private data and should only be accessed
using the provided API.
Since: 1.32
The QmiClientFox structure contains private data and should only be accessed
using the provided API.
Since: 1.32
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientFox
impl !Sync for QmiClientFox
impl Freeze for QmiClientFox
impl RefUnwindSafe for QmiClientFox
impl Unpin for QmiClientFox
impl UnsafeUnpin for QmiClientFox
impl UnwindSafe for QmiClientFox