#[repr(C)]pub struct QmiClientGas {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientGas structure contains private data and should only be accessed
using the provided API.
Since: 1.24
The QmiClientGas structure contains private data and should only be accessed
using the provided API.
Since: 1.24
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientGas
impl !Sync for QmiClientGas
impl Freeze for QmiClientGas
impl RefUnwindSafe for QmiClientGas
impl Unpin for QmiClientGas
impl UnsafeUnpin for QmiClientGas
impl UnwindSafe for QmiClientGas