#[repr(C)]pub struct QmiClientGms {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientGms structure contains private data and should only be accessed
using the provided API.
Since: 1.26
The QmiClientGms structure contains private data and should only be accessed
using the provided API.
Since: 1.26
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientGms
impl !Sync for QmiClientGms
impl Freeze for QmiClientGms
impl RefUnwindSafe for QmiClientGms
impl Unpin for QmiClientGms
impl UnsafeUnpin for QmiClientGms
impl UnwindSafe for QmiClientGms