#[repr(C)]pub struct QmiClientIms {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientIms structure contains private data and should only be accessed
using the provided API.
Since: 1.34
The QmiClientIms structure contains private data and should only be accessed
using the provided API.
Since: 1.34
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientIms
impl !Sync for QmiClientIms
impl Freeze for QmiClientIms
impl RefUnwindSafe for QmiClientIms
impl Unpin for QmiClientIms
impl UnsafeUnpin for QmiClientIms
impl UnwindSafe for QmiClientIms