#[repr(C)]pub struct QmiClientImsa {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientImsa structure contains private data and should only be accessed
using the provided API.
Since: 1.34
The QmiClientImsa structure contains private data and should only be accessed
using the provided API.
Since: 1.34
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientImsa
impl !Sync for QmiClientImsa
impl Freeze for QmiClientImsa
impl RefUnwindSafe for QmiClientImsa
impl Unpin for QmiClientImsa
impl UnsafeUnpin for QmiClientImsa
impl UnwindSafe for QmiClientImsa