#[repr(C)]pub struct QmiClientLoc {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientLoc structure contains private data and should only be accessed
using the provided API.
Since: 1.0
The QmiClientLoc structure contains private data and should only be accessed
using the provided API.
Since: 1.0
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientLoc
impl !Sync for QmiClientLoc
impl Freeze for QmiClientLoc
impl RefUnwindSafe for QmiClientLoc
impl Unpin for QmiClientLoc
impl UnsafeUnpin for QmiClientLoc
impl UnwindSafe for QmiClientLoc