#[repr(C)]pub struct QmiClientNas {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientNas structure contains private data and should only be accessed
using the provided API.
Since: 1.0
The QmiClientNas structure contains private data and should only be accessed
using the provided API.
Since: 1.0
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientNas
impl !Sync for QmiClientNas
impl Freeze for QmiClientNas
impl RefUnwindSafe for QmiClientNas
impl Unpin for QmiClientNas
impl UnsafeUnpin for QmiClientNas
impl UnwindSafe for QmiClientNas