#[repr(C)]pub struct QmiClientPbm {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientPbm structure contains private data and should only be accessed
using the provided API.
Since: 1.6
The QmiClientPbm structure contains private data and should only be accessed
using the provided API.
Since: 1.6
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientPbm
impl !Sync for QmiClientPbm
impl Freeze for QmiClientPbm
impl RefUnwindSafe for QmiClientPbm
impl Unpin for QmiClientPbm
impl UnsafeUnpin for QmiClientPbm
impl UnwindSafe for QmiClientPbm