#[repr(C)]pub struct QmiClientPdc {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientPdc structure contains private data and should only be accessed
using the provided API.
Since: 1.18
The QmiClientPdc structure contains private data and should only be accessed
using the provided API.
Since: 1.18
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientPdc
impl !Sync for QmiClientPdc
impl Freeze for QmiClientPdc
impl RefUnwindSafe for QmiClientPdc
impl Unpin for QmiClientPdc
impl UnsafeUnpin for QmiClientPdc
impl UnwindSafe for QmiClientPdc