#[repr(C)]pub struct QmiClientPds {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientPds structure contains private data and should only be accessed
using the provided API.
Since: 1.0
The QmiClientPds structure contains private data and should only be accessed
using the provided API.
Since: 1.0
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientPds
impl !Sync for QmiClientPds
impl Freeze for QmiClientPds
impl RefUnwindSafe for QmiClientPds
impl Unpin for QmiClientPds
impl UnsafeUnpin for QmiClientPds
impl UnwindSafe for QmiClientPds