#[repr(C)]pub struct QmiClientQos {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientQos structure contains private data and should only be accessed
using the provided API.
Since: 1.0
The QmiClientQos structure contains private data and should only be accessed
using the provided API.
Since: 1.0
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientQos
impl !Sync for QmiClientQos
impl Freeze for QmiClientQos
impl RefUnwindSafe for QmiClientQos
impl Unpin for QmiClientQos
impl UnsafeUnpin for QmiClientQos
impl UnwindSafe for QmiClientQos