#[repr(C)]pub struct QmiClientSar {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientSar structure contains private data and should only be accessed
using the provided API.
Since: 1.28
The QmiClientSar structure contains private data and should only be accessed
using the provided API.
Since: 1.28
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientSar
impl !Sync for QmiClientSar
impl Freeze for QmiClientSar
impl RefUnwindSafe for QmiClientSar
impl Unpin for QmiClientSar
impl UnsafeUnpin for QmiClientSar
impl UnwindSafe for QmiClientSar