#[repr(C)]pub struct QmiClientSsc {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientSsc structure contains private data and should only be accessed
using the provided API.
Since: 1.34
The QmiClientSsc structure contains private data and should only be accessed
using the provided API.
Since: 1.34
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientSsc
impl !Sync for QmiClientSsc
impl Freeze for QmiClientSsc
impl RefUnwindSafe for QmiClientSsc
impl Unpin for QmiClientSsc
impl UnsafeUnpin for QmiClientSsc
impl UnwindSafe for QmiClientSsc