#[repr(C)]pub struct QmiClientUim {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientUim structure contains private data and should only be accessed
using the provided API.
Since: 1.6
The QmiClientUim structure contains private data and should only be accessed
using the provided API.
Since: 1.6
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientUim
impl !Sync for QmiClientUim
impl Freeze for QmiClientUim
impl RefUnwindSafe for QmiClientUim
impl Unpin for QmiClientUim
impl UnsafeUnpin for QmiClientUim
impl UnwindSafe for QmiClientUim