#[repr(C)]pub struct QmiClientVoice {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientVoice structure contains private data and should only be accessed
using the provided API.
Since: 1.14
The QmiClientVoice structure contains private data and should only be accessed
using the provided API.
Since: 1.14
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientVoice
impl !Sync for QmiClientVoice
impl Freeze for QmiClientVoice
impl RefUnwindSafe for QmiClientVoice
impl Unpin for QmiClientVoice
impl UnsafeUnpin for QmiClientVoice
impl UnwindSafe for QmiClientVoice