#[repr(C)]pub struct QmiClientWda {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientWda structure contains private data and should only be accessed
using the provided API.
Since: 1.10
The QmiClientWda structure contains private data and should only be accessed
using the provided API.
Since: 1.10
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientWda
impl !Sync for QmiClientWda
impl Freeze for QmiClientWda
impl RefUnwindSafe for QmiClientWda
impl Unpin for QmiClientWda
impl UnsafeUnpin for QmiClientWda
impl UnwindSafe for QmiClientWda