#[repr(C)]pub struct QmiClientWds {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientWds structure contains private data and should only be accessed
using the provided API.
Since: 1.0
The QmiClientWds structure contains private data and should only be accessed
using the provided API.
Since: 1.0
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientWds
impl !Sync for QmiClientWds
impl Freeze for QmiClientWds
impl RefUnwindSafe for QmiClientWds
impl Unpin for QmiClientWds
impl UnsafeUnpin for QmiClientWds
impl UnwindSafe for QmiClientWds