#[repr(C)]pub struct QmiClientWms {
pub parent: QmiClient,
pub priv_unused: gpointer,
}Expand description
The QmiClientWms structure contains private data and should only be accessed
using the provided API.
Since: 1.0
The QmiClientWms structure contains private data and should only be accessed
using the provided API.
Since: 1.0
Fields
parent: QmiClientpriv_unused: gpointerAuto Trait Implementations
impl !Send for QmiClientWms
impl !Sync for QmiClientWms
impl Freeze for QmiClientWms
impl RefUnwindSafe for QmiClientWms
impl Unpin for QmiClientWms
impl UnsafeUnpin for QmiClientWms
impl UnwindSafe for QmiClientWms