QmiDeprecatedIndicationLocPositionReportOutputDilutionOfPrecision

Struct QmiDeprecatedIndicationLocPositionReportOutputDilutionOfPrecision 

#[repr(C)]
pub struct QmiDeprecatedIndicationLocPositionReportOutputDilutionOfPrecision { pub position_dilution_of_precision: gfloat, pub horizontal_dilution_of_precision: gfloat, pub vertical_dilution_of_precision: gfloat, }
A QmiIndicationLocPositionReportOutputDilutionOfPrecision struct.

position_dilution_of_precision: a gfloat.
horizontal_dilution_of_precision: a gfloat.
vertical_dilution_of_precision: a gfloat.

This type is deprecated and there is no replacement as the
new methods don’t require any intermediate type any more.

Since: 1.22
Deprecated: 1.32
A QmiIndicationLocPositionReportOutputDilutionOfPrecision struct.

position_dilution_of_precision: a gfloat.
horizontal_dilution_of_precision: a gfloat.
vertical_dilution_of_precision: a gfloat.

This type is deprecated and there is no replacement as the
new methods don’t require any intermediate type any more.

Since: 1.22
Deprecated: 1.32

Fields

position_dilution_of_precision: gfloathorizontal_dilution_of_precision: gfloatvertical_dilution_of_precision: gfloat