#[repr(C)]pub struct QmiDeprecatedIndicationLocPositionReportOutputGpsTime {
pub gps_weeks: guint16,
pub gps_time_of_week_milliseconds: guint32,
}Expand description
A QmiIndicationLocPositionReportOutputGpsTime struct.
gps_weeks: a guint16.
gps_time_of_week_milliseconds: a guint32.
This type is deprecated and there is no replacement as the
new methods don’t require any intermediate type any more.
Since: 1.22
Deprecated: 1.32
A QmiIndicationLocPositionReportOutputGpsTime struct.
gps_weeks: a guint16.
gps_time_of_week_milliseconds: a guint32.
This type is deprecated and there is no replacement as the
new methods don’t require any intermediate type any more.
Since: 1.22
Deprecated: 1.32
Fields
gps_weeks: guint16gps_time_of_week_milliseconds: guint32Auto Trait Implementations
impl Freeze for QmiDeprecatedIndicationLocPositionReportOutputGpsTime
impl RefUnwindSafe for QmiDeprecatedIndicationLocPositionReportOutputGpsTime
impl Send for QmiDeprecatedIndicationLocPositionReportOutputGpsTime
impl Sync for QmiDeprecatedIndicationLocPositionReportOutputGpsTime
impl Unpin for QmiDeprecatedIndicationLocPositionReportOutputGpsTime
impl UnsafeUnpin for QmiDeprecatedIndicationLocPositionReportOutputGpsTime
impl UnwindSafe for QmiDeprecatedIndicationLocPositionReportOutputGpsTime