#[repr(transparent)]pub struct QmiDeviceOpenFlags(pub c_uint);Expand description
Flags to specify which actions to be performed when the device is open.
Since: 1.0
Tuple Fields
0: c_uintImplementations
Sourceimpl QmiDeviceOpenFlags
impl QmiDeviceOpenFlags
Sourcepub const NONE: QmiDeviceOpenFlags
pub const NONE: QmiDeviceOpenFlags
No flags.
Sourcepub const VERSION_INFO: QmiDeviceOpenFlags
pub const VERSION_INFO: QmiDeviceOpenFlags
Run version info check when opening. Since 1.24.4 this flag no longer prevents requests from being sent to the modem if they’re assumed not supported based on the version info of each message.
Sourcepub const SYNC: QmiDeviceOpenFlags
pub const SYNC: QmiDeviceOpenFlags
Synchronize with endpoint once the device is open. Will release any previously allocated client ID.
Sourcepub const NET_802_3: QmiDeviceOpenFlags
pub const NET_802_3: QmiDeviceOpenFlags
Set network port to “802.3” mode; mutually exclusive with QMI_DEVICE_OPEN_FLAGS_NET_RAW_IP
Sourcepub const NET_RAW_IP: QmiDeviceOpenFlags
pub const NET_RAW_IP: QmiDeviceOpenFlags
Set network port to “raw IP” mode; mutally exclusive with QMI_DEVICE_OPEN_FLAGS_NET_802_3
Sourcepub const NET_QOS_HEADER: QmiDeviceOpenFlags
pub const NET_QOS_HEADER: QmiDeviceOpenFlags
Set network port to transmit/receive QoS headers; mutually exclusive with QMI_DEVICE_OPEN_FLAGS_NET_NO_QOS_HEADER
Sourcepub const NET_NO_QOS_HEADER: QmiDeviceOpenFlags
pub const NET_NO_QOS_HEADER: QmiDeviceOpenFlags
Set network port to not transmit/receive QoS headers; mutually exclusive with QMI_DEVICE_OPEN_FLAGS_NET_QOS_HEADER
Sourcepub const PROXY: QmiDeviceOpenFlags
pub const PROXY: QmiDeviceOpenFlags
Try to open the port through the ‘qmi-proxy’. Since 1.8.
Sourcepub const MBIM: QmiDeviceOpenFlags
pub const MBIM: QmiDeviceOpenFlags
Open an MBIM port with QMUX tunneling service. Since 1.16.
Sourcepub const AUTO: QmiDeviceOpenFlags
pub const AUTO: QmiDeviceOpenFlags
Open a port either in QMI or MBIM mode, depending on device driver. Since 1.18.
Sourcepub const EXPECT_INDICATIONS: QmiDeviceOpenFlags
pub const EXPECT_INDICATIONS: QmiDeviceOpenFlags
Explicitly state that indications are wanted (implicit in QMI mode, optional when in MBIM mode).