#[repr(transparent)]pub struct QmiDmsPowerState(pub c_uint);Expand description
Flags specifying the current power state.
If QMI_DMS_POWER_STATE_EXTERNAL_SOURCE is set, the device is powerered by an
external source; otherwise it is powered by a battery.
If QMI_DMS_POWER_STATE_BATTERY_CONNECTED is set, the battery is connected;
otherwise the battery is not connected.
If QMI_DMS_POWER_STATE_BATTERY_CHARGING is set, the battery is being charged;
otherwise the battery is not being charged.
If QMI_DMS_POWER_STATE_FAULT is set, a power fault has been detected.
Since: 1.0
Tuple Fields
0: c_uintImplementations
Sourceimpl QmiDmsPowerState
impl QmiDmsPowerState
Sourcepub const EXTERNAL_SOURCE: QmiDmsPowerState
pub const EXTERNAL_SOURCE: QmiDmsPowerState
Powered by an external source.
Sourcepub const BATTERY_CONNECTED: QmiDmsPowerState
pub const BATTERY_CONNECTED: QmiDmsPowerState
Battery is connected.
Sourcepub const BATTERY_CHARGING: QmiDmsPowerState
pub const BATTERY_CHARGING: QmiDmsPowerState
Battery is currently being charged.
Sourcepub const FAULT: QmiDmsPowerState
pub const FAULT: QmiDmsPowerState
Recognized power fault.