#[repr(transparent)]pub struct QmiGasFirmwareAutoSimMode(pub c_uint);Expand description
Automatic carrier switch according to the SIM mode.
QMI_GAS_FIRMWARE_AUTO_SIM_DISABLE: Disable the automatic carrier switch according to the SIM.
QMI_GAS_FIRMWARE_AUTO_SIM_ENABLE: Enable the automatic carrier switch according to the SIM.
QMI_GAS_FIRMWARE_AUTO_SIM_ENABLE_ONE_SHOT: Enable the automatic carrier switch according to the SIM just for one time.
QMI_GAS_FIRMWARE_AUTO_SIM_PENDING_ONE_SHOT: Indicate the pending status of a single switch (used only in DMS Get Firmware Auto Sim).
Since: 1.36
Tuple Fields
0: c_uintImplementations
Sourceimpl QmiGasFirmwareAutoSimMode
impl QmiGasFirmwareAutoSimMode
pub const QMI_GAS_FIRMWARE_AUTO_SIM_DISABLE: QmiGasFirmwareAutoSimMode
pub const QMI_GAS_FIRMWARE_AUTO_SIM_ENABLE: QmiGasFirmwareAutoSimMode
pub const QMI_GAS_FIRMWARE_AUTO_SIM_ENABLE_ONE_SHOT: QmiGasFirmwareAutoSimMode
pub const QMI_GAS_FIRMWARE_AUTO_SIM_PENDING_ONE_SHOT: QmiGasFirmwareAutoSimMode