QmiLocTimeSource

Struct QmiLocTimeSource 

#[repr(transparent)]
pub struct QmiLocTimeSource(pub c_uint);
Source of the used time.

Since 1.22

Tuple Fields

0: c_uint

Implementations

Source

impl QmiLocTimeSource

pub const INVALID: QmiLocTimeSource

Invalid.

pub const NETWORK_TIME_TRANSFER: QmiLocTimeSource

Time is set by the 1X system.

pub const NETWORK_TIME_TAGGING: QmiLocTimeSource

Time is set by WCDMA/GSM time tagging.

pub const EXTERNAL_INPUT: QmiLocTimeSource

Time set by external injection.

pub const TOW_DECODE: QmiLocTimeSource

Time is set after decoding over-the-air GPS navigation data from one GPS satellite.

pub const TOW_CONFIRMED: QmiLocTimeSource

Time is set after decoding over-the-air GPS navigation data from multiple satellites.

pub const TOW_AND_WEEK_CONFIRMED: QmiLocTimeSource

Both time of the week and GPS week number are known.

pub const NAVIGATION_SOLUTION: QmiLocTimeSource

Time is set by the position engine after the fix is obtained.

pub const SOLVE_FOR_TIME: QmiLocTimeSource

Time is set by the position engine after performing SFT.

pub const GLO_TOW_DECODE: QmiLocTimeSource

Time is set after decoding QZSS satellites.

pub const TIME_TRANSFORM: QmiLocTimeSource

Time is set after transforming the GPS to GLO time.

pub const WCDMA_SLEEP_TIME_TAG: QmiLocTimeSource

Time is set by the sleep time tag provided by the WCDMA network.

pub const GSM_SLEEP_TIME_TAG: QmiLocTimeSource

Time is set by the sleep time tag provided by the GSM network.

pub const UNKNOWN: QmiLocTimeSource

Unknown.

pub const SYSTEM_TIMETICK: QmiLocTimeSource

Time is derived from the system clock.

pub const QZSS_TOW_DECODE: QmiLocTimeSource

Time set after decoding QZSS satellites.

pub const BDS_TOW_DECODE: QmiLocTimeSource

Time set after decoding BDS satellites.