QmiMessageNasGetCellLocationInfoOutputGeranInfoCellElement

Struct QmiMessageNasGetCellLocationInfoOutputGeranInfoCellElement 

#[repr(C)]
pub struct QmiMessageNasGetCellLocationInfoOutputGeranInfoCellElement { pub cell_id: guint32, pub plmn: *mut gchar, pub lac: guint16, pub geran_absolute_rf_channel_number: guint16, pub base_station_identity_code: guint8, pub rx_level: guint16, }
GERAN info cell.

cell_id: a guint32.
plmn: a string of exactly 3 characters.
lac: a guint16.
geran_absolute_rf_channel_number: a guint16.
base_station_identity_code: a guint8.
rx_level: a guint16.

This type is deprecated and returns always an empty plmn string.

Since: 1.10
Deprecated: 1.26.6.
GERAN info cell.

cell_id: a guint32.
plmn: a string of exactly 3 characters.
lac: a guint16.
geran_absolute_rf_channel_number: a guint16.
base_station_identity_code: a guint8.
rx_level: a guint16.

This type is deprecated and returns always an empty plmn string.

Since: 1.10
Deprecated: 1.26.6.

Fields

cell_id: guint32plmn: *mut gcharlac: guint16geran_absolute_rf_channel_number: guint16base_station_identity_code: guint8rx_level: guint16