QmiMessageUimGetCardStatusOutputCardStatusCardsElementApplicationsElement

Struct QmiMessageUimGetCardStatusOutputCardStatusCardsElementApplicationsElement 

#[repr(C)]
pub struct QmiMessageUimGetCardStatusOutputCardStatusCardsElementApplicationsElement {
Show 14 fields pub type_: QmiUimCardApplicationType, pub state: QmiUimCardApplicationState, pub personalization_state: QmiUimCardApplicationPersonalizationState, pub personalization_feature: QmiUimCardApplicationPersonalizationFeature, pub personalization_retries: guint8, pub personalization_unblock_retries: guint8, pub application_identifier_value: *mut GArray, pub upin_replaces_pin1: gboolean, pub pin1_state: QmiUimPinState, pub pin1_retries: guint8, pub puk1_retries: guint8, pub pin2_state: QmiUimPinState, pub pin2_retries: guint8, pub puk2_retries: guint8,
}
A QmiMessageUimGetCardStatusOutputCardStatusCardsElementApplicationsElement struct.

type: a QmiUimCardApplicationType.
state: a QmiUimCardApplicationState.
personalization_state: a QmiUimCardApplicationPersonalizationState.
personalization_feature: a QmiUimCardApplicationPersonalizationFeature.
personalization_retries: a guint8.
personalization_unblock_retries: a guint8.
application_identifier_value: a GArray of guint8 elements.
upin_replaces_pin1: a gboolean.
pin1_state: a QmiUimPinState.
pin1_retries: a guint8.
puk1_retries: a guint8.
pin2_state: a QmiUimPinState.
pin2_retries: a guint8.
puk2_retries: a guint8.

This type is binary compatible with QmiMessageUimGetCardStatusOutputCardStatusCardsElementApplicationsElementV2
as the size and format of both structs is the same. The only thing that changed is the
representation of one of the enumeration fields.

Since: 1.10
Deprecated: 1.34. Use QmiMessageUimGetCardStatusOutputCardStatusCardsElementApplicationsElementV2 instead.
A QmiMessageUimGetCardStatusOutputCardStatusCardsElementApplicationsElement struct.

type: a QmiUimCardApplicationType.
state: a QmiUimCardApplicationState.
personalization_state: a QmiUimCardApplicationPersonalizationState.
personalization_feature: a QmiUimCardApplicationPersonalizationFeature.
personalization_retries: a guint8.
personalization_unblock_retries: a guint8.
application_identifier_value: a GArray of guint8 elements.
upin_replaces_pin1: a gboolean.
pin1_state: a QmiUimPinState.
pin1_retries: a guint8.
puk1_retries: a guint8.
pin2_state: a QmiUimPinState.
pin2_retries: a guint8.
puk2_retries: a guint8.

This type is binary compatible with QmiMessageUimGetCardStatusOutputCardStatusCardsElementApplicationsElementV2
as the size and format of both structs is the same. The only thing that changed is the
representation of one of the enumeration fields.

Since: 1.10
Deprecated: 1.34. Use QmiMessageUimGetCardStatusOutputCardStatusCardsElementApplicationsElementV2 instead.

Fields

type_: QmiUimCardApplicationTypestate: QmiUimCardApplicationStatepersonalization_state: QmiUimCardApplicationPersonalizationStatepersonalization_feature: QmiUimCardApplicationPersonalizationFeaturepersonalization_retries: guint8personalization_unblock_retries: guint8application_identifier_value: *mut GArrayupin_replaces_pin1: gbooleanpin1_state: QmiUimPinStatepin1_retries: guint8puk1_retries: guint8pin2_state: QmiUimPinStatepin2_retries: guint8puk2_retries: guint8