#[repr(C)]pub struct QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElementGir {
pub slot: *mut GPtrArray,
}Expand description
A QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElementGir struct.
slot: (element-type QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElementSlotElement): an array of QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElementSlotElement elements.
This type is a version of QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElement, using arrays of pointers to
structs instead of arrays of structs, for easier binding in other languages.
Since: 1.32
A QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElementGir struct.
slot: (element-type QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElementSlotElement): an array of QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElementSlotElement elements.
This type is a version of QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElement, using arrays of pointers to
structs instead of arrays of structs, for easier binding in other languages.
Since: 1.32
Fields
slot: *mut GPtrArrayTrait Implementations
Sourceimpl Clone for QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElementGir
impl Clone for QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElementGir
Sourcefn clone(
&self,
) -> QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElementGir
fn clone( &self, ) -> QmiMessageUimGetConfigurationOutputPersonalizationStatusOtherElementGir
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more