#[repr(transparent)]pub struct QmiWmsCdmaErrorClass(pub c_uint);Expand description
Error class reported from the network when failed to send an SMS in CDMA,
or reported by the device when failed to process a transfer-only CDMA message.
Since: 1.0
Tuple Fields
0: c_uintImplementations
Sourceimpl QmiWmsCdmaErrorClass
impl QmiWmsCdmaErrorClass
Sourcepub const TEMPORARY: QmiWmsCdmaErrorClass
pub const TEMPORARY: QmiWmsCdmaErrorClass
Temporary error reported by network.
Sourcepub const PERMANENT: QmiWmsCdmaErrorClass
pub const PERMANENT: QmiWmsCdmaErrorClass
Permanent error reported by network.
Sourcepub const TEMPORARY_DEVICE: QmiWmsCdmaErrorClass
pub const TEMPORARY_DEVICE: QmiWmsCdmaErrorClass
Temporary error reported by device. Since 1.28.
Sourcepub const PERMANENT_DEVICE: QmiWmsCdmaErrorClass
pub const PERMANENT_DEVICE: QmiWmsCdmaErrorClass
Permanent error reported by device. Since 1.28.