pub unsafe extern "C" fn qmi_client_dms_validate_service_programming_code(
self_: *mut QmiClientDms,
input: *mut QmiMessageDmsValidateServiceProgrammingCodeInput,
timeout: guint,
cancellable: *mut GCancellable,
callback: GAsyncReadyCallback,
user_data: gpointer,
)Expand description
Asynchronously sends a Validate Service Programming Code request to the device.
self: a QmiClientDms.
input: a QmiMessageDmsValidateServiceProgrammingCodeInput.
timeout: maximum time to wait for the method to complete, in seconds.
cancellable: a GCancellable or NULL.
callback: a GAsyncReadyCallback to call when the request is satisfied.
user_data: user data to pass to callback.
When the operation is finished, callback will be invoked in the thread-default main loop of the thread you are calling this method from.
You can then call qmi_client_dms_validate_service_programming_code_finish() to get the result of the operation.
Since: 1.0